#!/bin/bash
#
# source: ftp.easysw.com/pub/cups/1.3.9/cups-1.3.9-source.tar.bz2
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="cups"
softversion="1.3.9"
arch="i486"
cpu="i686"
packageversion="54.2"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion-source.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

    |-----handy-ruler-------------------------------------------------------|
cups: cups (Common UNIX Printing System)
cups:
cups: The Common UNIX Printing System provides a portable printing layer for
cups: UNIX(R)-like operating systems. It has been developed by Easy Software
cups: Products to promote a standard printing solution for all UNIX vendors
cups: and users.  CUPS uses the Internet Printing Protocol ("IPP") as the
cups: basis for managing print jobs and queues.  The CUPS package includes
cups: System V and Berkeley command-line interfaces, a PostScript RI
cups: package for supporting non-PostScript printer drivers, and tools for
cups: creating additional printer drivers and other CUPS services.
cups:
EODESC

cd $src

cat $buildir/str2974.patch | patch -p0 --verbose || exit 1

#------------------Start Configure
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --with-docdir=/usr/doc/$soft-$softversion \
  --enable-slp=no \
  --enable-ldap=no \
  --enable-gnutls=no \
  --enable-cdsassl=no \
  --enable-pam=no \
  --without-php

make -j2 || exit 1
make BUILDROOT=$dest install || exit 1

# Handle this as a config file, and non-executable in a default install:
#mv $dest/etc/rc.d/init.d/cups $dest/etc/rc.d/rc.cups.new
#chmod 755 $dest/etc/rc.d/rc.cups.new
# Clear out the additions:
#rm -rf $dest/etc/rc.d/*.d

# I'm not sure if overwriting this blindly could have ill effects,
# but it never hurts to play it safe.  According to the dbus-daemon
# manpage, only files ending in .conf will be used, so there won't
# be any unintended doubling up.
mv $dest/etc/dbus-1/system.d/cups.conf $dest/etc/dbus-1/system.d/cups.conf.new

# For full CUPS SMB support, you'll need to install the cups-samba
# package from the source in this directory.  There's no easy way
# to add that to a package build, and the requests aren't pouring in,
# so you'll have to install it yourself.  It's easy to do.

# However, this will get you the most useful SMB support for free.
# Thanks to Boris Kurktchiev for the tip.  :-)

( cd $dest/usr/lib/cups/backend
  if [ ! -e smb ]; then
    ln -sf /usr/bin/smbspool smb
  fi
)

cat $dest/etc/rc.d/init.d/cups > $dest/etc/rc.d/rc.cups.new
chmod 755 $dest/etc/rc.d/rc.cups.new
rm -rf $dest/etc/rc.d/*.d

# I'm sorry, but PDF files are almost as bloated and annoying as
# MS Word documents.  We'll retain the HTML files in /usr/doc.
( cd $dest/usr/doc
  find . -name "*.pdf" -exec rm -f {} \; )

# Apply no-clobber fix to conffiles:
( cd $dest/etc/cups
  for file in * ; do
    if [ -f $file ]; then
      mv $file $file.new
    fi
  done )

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Use symlinks to certain binaries so that CUPS and LPRng can coexist:
SUFFIX=cups
for file in \
usr/bin/cancel \
usr/bin/lp \
usr/bin/lpq \
usr/bin/lpr \
usr/bin/lprm \
usr/bin/lpstat \
usr/sbin/lpc ; do
  ( cd $dest
    mv ${file} ${file}-${SUFFIX}
    ( cd `dirname ${file}` ; ln -sf `basename ${file}`-${SUFFIX} `basename ${file}` )
  )
done

# Now fix the associated man pages:
mv $dest/usr/man/man1/cancel.1.gz $dest/usr/man/man1/cancel-${SUFFIX}.1.gz
mv $dest/usr/man/man1/lp.1.gz $dest/usr/man/man1/lp-${SUFFIX}.1.gz
mv $dest/usr/man/man1/lpq.1.gz $dest/usr/man/man1/lpq-${SUFFIX}.1.gz
mv $dest/usr/man/man1/lpr.1.gz $dest/usr/man/man1/lpr-${SUFFIX}.1.gz
mv $dest/usr/man/man1/lprm.1.gz $dest/usr/man/man1/lprm-${SUFFIX}.1.gz
mv $dest/usr/man/man1/lpstat.1.gz $dest/usr/man/man1/lpstat-${SUFFIX}.1.gz
mv $dest/usr/man/man8/lpc.8.gz $dest/usr/man/man8/lpc-${SUFFIX}.8.gz
( cd $dest/usr/man/man1
  ln -sf cancel-${SUFFIX}.1.gz cancel.1.gz
  ln -sf lp-${SUFFIX}.1.gz lp.1.gz
  ln -sf lpq-${SUFFIX}.1.gz lpq.1.gz
  ln -sf lpr-${SUFFIX}.1.gz lpr.1.gz
  ln -sf lprm-${SUFFIX}.1.gz lprm.1.gz
  ln -sf lpstat-${SUFFIX}.1.gz lpstat.1.gz
)
( cd $dest/usr/man/man8
  ln -sf lpc-${SUFFIX}.8.gz lpc.8.gz
)

# Add the doinst.sh that installs the .new conffiles:
zcat $buildir/doinst.sh.gz > $dest/install/doinst.sh

# Desktop file

rm -f $dest/usr/share/applications/cups.desktop

cat << "EOF" > $dest/usr/share/applications/cups.desktop
[Desktop Entry]
Categories=Application;System;
Encoding=UTF-8
Exec=iceweasel http://localhost:631/
GenericName=
Icon=cups
MimeType=
Path=
StartupNotify=false
Terminal=false
TerminalOptions=
Type=Application
X-DCOP-ServiceType=
X-KDE-SubstituteUID=false
X-KDE-Username=
Name=Cups webconf
Comment=CUPS Web Interface
Name[de]=Cups webconf
Comment[de]=CUPS Webinterface
Name[en_US]=Cups webconf
Comment[en_US]=CUPS Web Interface
Name[es]=Cups webconf
Comment[es]=Interfaz Web de CUPS
Name[et]=Cups webconf
Comment[et]=CUPS-i veebiliides
Name[fr]=Cups webconf
Comment[fr]=Interface Web de CUPS
Name[he]=נהל הדפסות
Comment[he]=ממשק דפדפן של CUPS
Name[id]=Cups webconf
Comment[id]=Antarmuka Web CUPS
Name[it]=Cups webconf
Comment[it]=Interfaccia web di CUPS
Name[ja]=印刷の管理
Comment[ja]=CUPS Web インタフェース
Name[pl]=Cups webconf
Comment[pl]=Interfejs WWW CUPS
Name[zh]=打印机管理
Comment[zh]=CUPS网页界面
Name[zh_TW]=印表管理
Comment[zh_TW]=CUPS 網頁介面
EOF

#-------------------Prepare the documentation:

cp -a \
   CHANGES.txt CREDITS.txt INSTALL.txt LICENSE.txt README.txt \
   $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion
cp $buildir/doinst.sh.gz $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5